html, body {
	padding-bottom: 3.5em;
}

#title {
	margin-bottom: .75vw;
	font-size: 7.5vw;
	text-align: center;
	font-weight: 600;

	color: white;
	background-color: black;
	background-image: url("/images/title_background.png");
	background-size: cover;
	background-position: center;
	border-radius: 6px;
	text-shadow: 0 0 10px #323232;
}

@media screen and (min-width: 1200px) {
  #title {
    font-size: 4vw;
    margin-bottom: 1.5vw;
  }
}

#footer {
	position: fixed;
	bottom: 0;
	left: 0;
	right: 0;

	margin-top: 1.5em;
	padding: 0.5em;

	background-color: white;
	border-top: 1px solid #bababa;

	text-align: center;
}

#abstract {
	margin-bottom: 1.5em;
	margin-top: 1em;
	font-size: 1.2em;
	text-align: justify;
}