
/* BiCroCom home stylesheet */

#main {
	padding-top: 1em;
}

.title-wrap {
	font-size: 2em;
	text-align: center;
}

#title {
	margin: -.1em 0;
	font-family: "Montserrat";
	font-size: 3em;
}

#pipelist {
	margin-top: 2em;
	text-align: center;
}

#pipelist .description {
	display: block;
	margin-top: 1em;
	margin-bottom: .5em;

	color: #323232;
	font-size: 2em;
}

#pipelist a {
	display: block;
	margin-bottom: .5em;

	font-size: 2.2em;
}

#pipelist h2 {
	margin-top: 1em;
	margin-bottom: 0.5em;

	font-family: "Montserrat";
	font-size: 2.5em;
	text-align: left;
}
