% include('header.tpl')

% if not home_status:
<script type="text/javascript">document.location = document.location + "probe-design/"</script>
% end

<div id="main" class="col col-md-6 offset-md-3">

	<div class="row">
		<div id="pipelist" class="col col-md-12">

			<h1>Choose a section:</h1><br />

			<a class="btn btn-primary" href="/probe-design/" role="button">Probe design</a>

		</div>
	</div>
</div>

% include('footer.tpl')